@@ -21,7 +21,6 @@ class AddDialogTest : public QObject
     Q_OBJECT
 
 private Q_SLOTS:
-    void initTestCase();
     void testBasicWidgets_data();
     void testBasicWidgets();
 
@@ -29,12 +28,6 @@ private:
     PluginManager m_pluginManager;
 };
 
-void AddDialogTest::initTestCase()
-{
-    // Avoid a runtime dependency on KLauncher.
-    qputenv("KDE_FORK_SLAVES", "yes");
-}
-
 void AddDialogTest::testBasicWidgets_data()
 {
     QTest::addColumn<QString>("mimeType");
